@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # copyright at the end of the file in the pod section
 
 package Config::Model::TkUI;
-$Config::Model::TkUI::VERSION = '1.354';
+$Config::Model::TkUI::VERSION = '1.355';
 use 5.10.1;
 use strict;
 use warnings;
@@ -145,7 +145,7 @@ sub Populate {
         [ command => 'check for errors',     -command => sub { $cw->check(1) } ],
         [ command => 'check for warnings',   -command => sub { $cw->check( 1, 1 ) } ],
         [ command => 'show unsaved changes', -command => sub { $cw->show_changes; } ],
-        [ qw/command save   -command/, sub { $cw->save } ],
+        [ command => 'save (Ctrl-s)', -command => sub { $cw->save } ],
         [
             command  => 'save in dir ...',
             -command => sub { $cw->save_in_dir; }
@@ -158,18 +158,21 @@ sub Populate {
                 Tk::ObjScanner::scan_object( $cw->{root} );
                 }
         ],
-        [ qw/command quit   -command/, sub { $cw->quit } ],
+        [ command => 'quit (Ctrl-q)', -command => sub { $cw->quit } ],
     ];
     $menubar->cascade( -label => 'File', -menuitems => $file_items );
 
     $cw->add_help_menu($menubar);
 
+    $cw->bind( '<Control-s>', sub { $cw->save } );
+    $cw->bind( '<Control-q>', sub { $cw->quit } );
+
     my $edit_items = [
 
         # [ qw/command cut   -command/, sub{ $cw->edit_cut }],
-        [ command => 'copy (Ctrl-C)',  '-command', sub { $cw->edit_copy } ],
-        [ command => 'paste (Ctrl-V)', '-command', sub { $cw->edit_paste } ],
-        [ command => 'find (Ctrl-F)',  '-command', sub { $cw->pack_find_widget; } ],
+        [ command => 'copy (Ctrl-c)',  '-command', sub { $cw->edit_copy } ],
+        [ command => 'paste (Ctrl-v)', '-command', sub { $cw->edit_paste } ],
+        [ command => 'find (Ctrl-f)',  '-command', sub { $cw->pack_find_widget; } ],
     ];
     $menubar->cascade( -label => 'Edit', -menuitems => $edit_items );
 
@@ -619,7 +622,7 @@ sub on_cut_buffer_dump {
 
     # display result
     $cw->reload;
-    $cw->create_element_widget('view');
+    $cw->create_element_widget($cw->{current_mode}, $tree_path);
 }
 
 # replace dot in str by _|_
@@ -667,6 +670,23 @@ sub disp_obj_elt {
     my ( $path,    $cw,       $opening, $fd_path )      = @$data_ref;
     my $tkt  = $cw->{tktree};
     my $mode = $tkt->getmode($path);
+
+    if ($cw->{show_only_custom}) {
+        my @new_element_list;
+        foreach my $elt ( @element_list ) {
+            my $elt_type = $node->element_type($elt);
+            my $obj= $node->fetch_element($elt);
+            if ($elt_type eq 'leaf') {
+                next unless defined $obj->fetch(qw/mode custom check no silent 1/) ;
+            }
+            if ($elt_type eq 'check_list') {
+                next unless $obj->get_checked_list(qw/mode custom/) ;
+            }
+            push @new_element_list, $elt;
+        }
+        @element_list = @new_element_list;
+    }
+
     $logger->trace( "disp_obj_elt path $path mode $mode opening $opening " . "(@element_list)" );
 
     $cw->prune( $path, @element_list );
@@ -923,12 +943,6 @@ sub disp_leaf {
     $tkt->itemCreate( $path, 2, -text => $cw->trim_value($value) );
 
     $tkt->itemCreate( $path, 3, -text => $cw->trim_value($std_v) );
-
-    my $meth =
-        ( $cw->{show_only_custom} and not( $is_customised or $has_error or $has_warning ) )
-        ? 'hide'
-        : 'show';
-    $tkt->$meth( entry => $path );
 }
 
 sub disp_node {
@@ -1039,6 +1053,8 @@ sub create_element_widget {
     my $widget = $widget_table{$mode}{$type}
         || die "Cannot find $mode widget for type $type";
     my @store = $mode eq 'edit' ? ( -store_cb => sub { $cw->reload(@_) } ) : ();
+    $cw->{current_mode} = $mode;
+
     $cw->{editor} = $e_frame->$widget(
         -item => $obj,
         -path => $tree_path,
@@ -1123,6 +1139,7 @@ sub edit_paste {
     }
 
     $cw->reload() if @$cut_buf;
+    $cw->create_element_widget($cw->{current_mode}, $selection);
 }
 
 sub wizard {
